# Disclaimer

This book has been generated with [Cyberaide
Bookmanager](https://pypi.python.org/pypi/cyberaide-bookmanager). 

Bookmanager is a tool to create a publication from a number of sources on the
internet. It is especially useful to create customized books, lecture notes, or
handouts. Content is best integrated in markdown format as it is very fast to
produce the output. 

Bookmanager has been developed based on our experience over the last 3 years
with a more sophisticated approach. Bookmanager takes the lessons from this
approach and distributes a tool that can easily be used by others.

The following
shields provide some information about it. Feel free to click on them.

[![Version](https://img.shields.io/pypi/v/cyberaide-bookmanager.svg)](https://pypi.python.org/pypi/cyberaide-bookmanager)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://github.com/cloudmesh/cyberaide-bookmanager/blob/master/LICENSE)
[![Python](https://img.shields.io/pypi/pyversions/cyberaide-bookmanager.svg)](https://pypi.python.org/pypi/cyberaide-bookmanager)
[![Format](https://img.shields.io/pypi/format/cyberaide-bookmanager.svg)](https://pypi.python.org/pypi/cyberaide-bookmanager)
[![Status](https://img.shields.io/pypi/status/cyberaide-bookmanager.svg)](https://pypi.python.org/pypi/cyberaide-bookmanager)
[![Travis](https://travis-ci.com/cloudmesh/cyberaide-bookmanager.svg?branch=master)](https://travis-ci.com/cloudmesh/cyberaide-bookmanager)

## Acknowledgment

If you use bookmanager to produce a document you must include the following
acknowledgement.

> "This document was produced with Cyberaide Bookmanager developed by Gregor von
> Laszewski available at https://pypi.python.org/pypi/cyberaide-bookmanager. It
> is in the responsibility of the user to make sure an author acknowledgement 
> section is included in your document. Copyright verification of content included
> in a book is responsibility of the book editor."

The bibtex entry is

```bash
@Misc{www-cyberaide-bookmanager,
  author = 	 {Gregor von Laszewski},
  title = 	 {{Cyberaide Book Manager}},
  howpublished = {pypi},
  month = 	 apr,
  year = 	 2019,
  url={https://pypi.org/project/cyberaide-bookmanager/}
}
```

## Extensions

We are happy to discuss with you bugs, issues and ideas for enhancements. 
Please use the convenient github issues at 

* <https://github.com/cyberaide/bookmanager/issues>

Please do not file with us issues that relate to an editors book. They will
provide you with their own mechanism on how to correct their content.
